# [BraineryWiz](https://www.silviasbrainery.com/brainerywiz)

[![PyPI version fury.io](https://badge.fury.io/py/BraineryWiz.svg)](https://pypi.python.org/pypi/BraineryWiz/)
[![Downloads](https://pepy.tech/badge/BraineryWiz)](https://pepy.tech/project/BraineryWiz)
[![Downloads](https://pepy.tech/badge/BraineryWiz/month)](https://pepy.tech/project/BraineryWiz)
[![Downloads](https://pepy.tech/badge/BraineryWiz/week)](https://pepy.tech/project/BraineryWiz)

**Main WebPage**: https://www.silviasbrainery.com/brainerywiz

**BraineyWiz Email Address:** <BraineryWiz@Gmail.com>


**Description:**

***An Element Independent Package for plotting FEM models***

## By: 

- **Bijan Sayyafzadeh**: [Github](https://github.com/BijanSeif), Email: <B.Sayyaf@yahoo.com>
- **Silvia Mazzoni**: [Github](https://github.com/silviamazzoni), Email: <SilviaMazzoni@yahoo.com>

